aboutsummaryrefslogtreecommitdiff
path: root/ext/js
diff options
context:
space:
mode:
Diffstat (limited to 'ext/js')
-rw-r--r--ext/js/background/backend.js4
-rw-r--r--ext/js/data/sandbox/array-buffer-util.js (renamed from ext/js/data/sandbox/string-util.js)4
-rw-r--r--ext/js/display/display-content-manager.js4
-rw-r--r--ext/js/media/audio-downloader.js4
-rw-r--r--ext/js/pages/settings/backup-controller.js4
5 files changed, 10 insertions, 10 deletions
diff --git a/ext/js/background/backend.js b/ext/js/background/backend.js
index f3c76311..a3694dd3 100644
--- a/ext/js/background/backend.js
+++ b/ext/js/background/backend.js
@@ -19,6 +19,7 @@
* AccessibilityController
* AnkiConnect
* AnkiUtil
+ * ArrayBufferUtil
* AudioDownloader
* ClipboardMonitor
* ClipboardReader
@@ -33,7 +34,6 @@
* ProfileConditionsUtil
* RequestBuilder
* ScriptManager
- * StringUtil
* Translator
* wanakana
*/
@@ -2223,7 +2223,7 @@ class Backend {
for (const item of results) {
const {content} = item;
if (content instanceof ArrayBuffer) {
- item.content = StringUtil.arrayBufferToBase64(content);
+ item.content = ArrayBufferUtil.arrayBufferToBase64(content);
}
}
return results;
diff --git a/ext/js/display/display-content-manager.js b/ext/js/display/display-content-manager.js
index 0b91b40c..bfba5fb8 100644
--- a/ext/js/display/display-content-manager.js
+++ b/ext/js/display/display-content-manager.js
@@ -16,7 +16,7 @@
*/
/* global
- * StringUtil
+ * ArrayBufferUtil
*/
/**
@@ -139,7 +139,7 @@ class DisplayContentManager {
const token = this._token;
const data = (await yomichan.api.getMedia([{path, dictionary}]))[0];
if (token === this._token && data !== null) {
- const buffer = StringUtil.base64ToArrayBuffer(data.content);
+ const buffer = ArrayBufferUtil.base64ToArrayBuffer(data.content);
const blob = new Blob([buffer], {type: data.mediaType});
const url = URL.createObjectURL(blob);
cachedData.data = data;
diff --git a/ext/js/media/audio-downloader.js b/ext/js/media/audio-downloader.js
index 4142e3f4..77e9afd2 100644
--- a/ext/js/media/audio-downloader.js
+++ b/ext/js/media/audio-downloader.js
@@ -16,11 +16,11 @@
*/
/* global
+ * ArrayBufferUtil
* JsonSchema
* NativeSimpleDOMParser
* RequestBuilder
* SimpleDOMParser
- * StringUtil
*/
class AudioDownloader {
@@ -283,7 +283,7 @@ class AudioDownloader {
throw new Error('Could not retrieve audio');
}
- const data = StringUtil.arrayBufferToBase64(arrayBuffer);
+ const data = ArrayBufferUtil.arrayBufferToBase64(arrayBuffer);
const contentType = response.headers.get('Content-Type');
return {data, contentType};
}
diff --git a/ext/js/pages/settings/backup-controller.js b/ext/js/pages/settings/backup-controller.js
index ba36a828..a232ce34 100644
--- a/ext/js/pages/settings/backup-controller.js
+++ b/ext/js/pages/settings/backup-controller.js
@@ -16,9 +16,9 @@
*/
/* global
+ * ArrayBufferUtil
* DictionaryController
* OptionsUtil
- * StringUtil
*/
class BackupController {
@@ -319,7 +319,7 @@ class BackupController {
}
async _importSettingsFile(file) {
- const dataString = StringUtil.arrayBufferUtf8Decode(await this._readFileArrayBuffer(file));
+ const dataString = ArrayBufferUtil.arrayBufferUtf8Decode(await this._readFileArrayBuffer(file));
const data = JSON.parse(dataString);
// Type check
diff --git a/ext/js/data/sandbox/string-util.js b/ext/js/data/sandbox/array-buffer-util.js
index de6933cd..13988e76 100644
--- a/ext/js/data/sandbox/string-util.js
+++ b/ext/js/data/sandbox/array-buffer-util.js
@@ -16,9 +16,9 @@
*/
/**
* Class containing generic string utility functions.
*/
-class StringUtil {
+class ArrayBufferUtil {
/**
* Decodes the contents of an ArrayBuffer using UTF8.
* @param {ArrayBuffer} arrayBuffer The input ArrayBuffer.
@@ -16,9 +16,9 @@
*/
/**
- * Class containing generic string utility functions.
+ * Class containing generic ArrayBuffer utility functions.
*/